#
# spec file for package baloo5
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _tar_path 5.56
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           baloo5
Version:        5.56.0
Release:        1.1
Summary:        Framework for searching and managing metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/baloo-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE fix-cmakelists-comments.diff -- Change cmake 3.0 block comments to work in cmake 2.x
Patch1:         fix-cmakelists-comments.diff
# PATCH-FIX-OPENSUSE
Patch2:         0001-Do-not-use-qfileinfo-metadatachangetime-if-Qt-lt-5.10.patch
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  libattr-devel
BuildRequires:  lmdb-devel
BuildRequires:  cmake(KF5Config) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Crash) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5FileMetaData) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5IdleTime) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(KF5Solid) >= %{_kf5_bugfix_version}
BuildRequires:  cmake(Qt5Concurrent) >= 5.6.0
BuildRequires:  cmake(Qt5Core) >= 5.6.0
BuildRequires:  cmake(Qt5DBus) >= 5.6.0
BuildRequires:  cmake(Qt5Qml) >= 5.6.0
BuildRequires:  cmake(Qt5Quick) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
BuildRequires:  cmake(Qt5Widgets) >= 5.6.0

%description
Baloo is a framework for searching and managing metadata.

%package -n libKF5Baloo5
Summary:        Core library for Baloo Framework
# The -lang package was split into components
Group:          System/GUI/KDE
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}

%description -n libKF5Baloo5
Baloo is a framework for searching and managing metadata. This
package contains Baloo's core library.

%package -n libKF5BalooEngine5
Summary:        Baloo Engine library
Group:          System/GUI/KDE
Recommends:     libKF5BalooEngine5-lang

%description -n libKF5BalooEngine5
Baloo is a framework for searching and managing metadata. This
package contains Baloo's Engine library.

%package file
Summary:        Filesearch components for Baloo Framework
Group:          System/GUI/KDE
Requires:       libQt5Sql5-sqlite
Recommends:     %{name}-file-lang
Provides:       baloo-file = %{version}
Obsoletes:      baloo-file < %{version}

%description file
Baloo is a framework for searching and managing metadata. This
package contains filesearch components.

%package kioslaves
Summary:        KIO slave components for Baloo Framework
Group:          System/GUI/KDE
Requires:       kded
Recommends:     %{name}-kioslaves-lang

%description kioslaves
Baloo is a framework for searching and managing metadata. This
package contains KIO slave components.

%package tools
Summary:        Aditional components for Baloo Framework
Group:          System/GUI/KDE
Recommends:     %{name}-tools-lang
Provides:       baloo-tools = %{version}
Obsoletes:      baloo-tools < %{version}

%description tools
Baloo is a framework for searching and managing metadata. This
package contains aditional command line utilities.

%package imports
Summary:        QML components for Baloo Framework
Group:          System/GUI/KDE
Recommends:     %{name}-imports-lang

%description imports
Baloo is a framework for searching and managing metadata. This
package contains QML imports.

%package devel
Summary:        Development package for baloo5
Group:          Development/Libraries/KDE
Requires:       libKF5Baloo5 = %{version}
Requires:       libKF5BalooEngine5 = %{version}
Requires:       lmdb-devel
Requires:       cmake(KF5CoreAddons) >= %{_kf5_bugfix_version}
Requires:       cmake(KF5FileMetaData) >= %{_kf5_bugfix_version}
Requires:       cmake(Qt5Core) >= 5.6.0
# DBus interface file
Conflicts:      baloo-devel

%description devel
Baloo is a framework for searching and managing metadata. This
package contains aditional command line utilities. Development files.

%lang_package -n libKF5BalooEngine5
%lang_package -n %{name}-file
%lang_package -n %{name}-tools
%lang_package -n %{name}-kioslaves
%lang_package -n %{name}-imports

%prep
%setup -q -n baloo-%{version}
%patch1 -p1
%patch2 -p1
%if 0%{?suse_version} == 1500
sed -i -e "s/^set *(REQUIRED_QT_VERSION 5.10.0)$/set(REQUIRED_QT_VERSION 5.9.0)/" CMakeLists.txt
%endif

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %make_jobs

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %{kf5_find_lang}
  # Split manually, kf5_find_lang doesn't support it...
  grep -E '^%%dir' %{name}.lang | tee %{name}-{file,tools,kioslaves}.lang >/dev/null
  grep -E '/balooengine5.mo$' %{name}.lang >> libKF5BalooEngine5.lang
  grep -E '/(balooctl5|baloo_file5|baloo_file_extractor5).mo$' %{name}.lang >> %{name}-file.lang
  grep -E '/(baloodb5|baloosearch5|balooshow5).mo$' %{name}.lang >> %{name}-tools.lang
  grep -E '/(kio5_baloosearch|kio5_tags|kio5_timeline).mo$' %{name}.lang >> %{name}-kioslaves.lang
  grep -E '/baloomonitorplugin.mo$' %{name}.lang >> %{name}-imports.lang

  rm %{name}.lang
%endif

%post -n libKF5Baloo5 -p /sbin/ldconfig
%postun -n libKF5Baloo5 -p /sbin/ldconfig
%post file -p /sbin/ldconfig
%postun file -p /sbin/ldconfig
%post -n libKF5BalooEngine5 -p /sbin/ldconfig
%postun -n libKF5BalooEngine5 -p /sbin/ldconfig

%files -n libKF5Baloo5
%license COPYING*
%{_kf5_libdir}/libKF5Baloo.so.*

%files -n libKF5BalooEngine5
%license COPYING*
%{_kf5_libdir}/libKF5BalooEngine.so.*

%files file
%license COPYING*
%{_kf5_bindir}/baloo_file
%{_kf5_bindir}/baloo_file_extractor
%{_kf5_bindir}/balooctl
%{_kf5_configdir}/autostart/baloo_file.desktop
%{_kf5_iconsdir}/hicolor/*/apps/baloo.png
%{_kf5_debugdir}/baloo.categories

%files kioslaves
%license COPYING*
%dir %{_kf5_plugindir}/kf5/kio
%dir %{_kf5_plugindir}/kf5
%{_kf5_plugindir}/kf5/kio/baloosearch.so
%{_kf5_servicesdir}/baloosearch.protocol
%dir %{_kf5_plugindir}/kf5/kded
%{_kf5_plugindir}/kf5/kded/baloosearchmodule.so
%{_kf5_plugindir}/kf5/kio/tags.so
%{_kf5_servicesdir}/tags.protocol
%{_kf5_plugindir}/kf5/kio/timeline.so
%{_kf5_servicesdir}/timeline.protocol

%files tools
%license COPYING*
%{_kf5_bindir}/baloosearch
%{_kf5_bindir}/balooshow

%files imports
%license COPYING*
%{_kf5_qmldir}/

%files devel
%license COPYING*
%dir %{_kf5_includedir}
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5Baloo/
%{_kf5_libdir}/libKF5Baloo.so
%{_kf5_libdir}/pkgconfig/Baloo.pc
%{_kf5_sharedir}/dbus-1/interfaces/*.xml
%{_kf5_mkspecsdir}/qt_Baloo.pri

%if %{with lang}
%files -n libKF5BalooEngine5-lang -f libKF5BalooEngine5.lang
%license COPYING*

%files file-lang -f %{name}-file.lang
%license COPYING*

%files tools-lang -f %{name}-tools.lang
%license COPYING*

%files kioslaves-lang -f %{name}-kioslaves.lang
%license COPYING*

%files imports-lang -f %{name}-imports.lang
%license COPYING*

%endif

%changelog
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Replace several Q_ASSERTs with proper checks
  * Check string length to avoid crash for "tags:/" URL
  * [tags_kio] Fix local file tagging by checking only tag: urls for double slashes.
  * add baloo engine debugging category
  * Hardcoding the Remaining Time Update Interval
  * Fix regression for matching explicitly included folders
  * Cleanup idempotent entries from mimetype mapper table
  * [baloo/KInotify] Notify if folder was moved from unwatched place (kde#342224)
  * Simplify term debug output
  * Handle folders matching substrings of included/excluded folders correctly
  * [balooctl] Normalize include/exclude pathes before using it for the config
  * Optimize Baloo::File copy assign operator, fix Baloo::File::load(url)
  * Use content to determine mime type
  * Get rid of mostly unused filePathToStat overload
  * [Extractor] Exclude GPG encrypted data from being indexed
  * [balooctl] Actually abort a malformed command instead of just saying so
  * [balooctl] Add missing help for "config set", normalize string
  * Replace recursive isDirHidden with iterative one, allow const argument
  * Make sure only directories are added to the inotify watcher
- Dropped patches, now upstream:
  * 0001-Check-string-length-to-avoid-crash-for-tags-URL.patch
* Wed Feb 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix crashing kdeinit, add
  0001-Check-string-length-to-avoid-crash-for-tags-URL.patch
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Do-not-use-qfileinfo-metadatachangetime-if-Qt-lt-5.10.patch to
  revert a change by upstream that removes support for Qt < 5.10
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix ResultIterator
  * [tags_kio] Disable access with a double slashed url, i.e. "tags://". (kde#400594)
  * Instantiate QApplication before KCrash/KCatalog
  * Ignore all non-storage deviceAdded signals from Solid
  * IndexerConfig: Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
  * Remove Qt 5.10 checks now that we require it as min version
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Extend PositionCodec unit tests, better code coverage
  * Move typesForMimeType helper from BasicIndexingJob to anonymous namespace
  * Fix mistakes introduced in a632a72a
  * Don't check if file is directory based on mime-type
  * Fixed link to the coding style wiki page
  * add documentation to result class
  * Move internal helper from BasicIndexingJob to anonymous namespace
  * Add "image/svg" as Type::Image to the BasicIndexingJob
  * Minor optimization and cleanup for PositionCodec
  * Avoid potential nullptr access for Document, use reference instead
  * RFC: Add unit test for splitting of numbers in TermGenerator
  * Use Compact json formatting for storing document metadata
  * Remove unused map() getter from Result
  * remove unused docId from result
  * Use escaped UTF-8 sequence instead of Latin1 characters, minor cleanups
  * Treat uints the same as ints
  * Add unittest to check if commiting the same change twice works
  * Add unit test for position DB
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Remove duplicated code for rating property
  * Extend unit tests to check comparisons of multi-digit numeric properties
  * Fix searches for rating 10 (5 stars) (kde#357960)
  * Remove extra spaces from Debug output, insert delimiters between fields
  * Use isEmpty()
  * Avoid writing unchanged data to terms dbs
  * Reserve space in pending operations vector
  * Remove unused QByteArray include
  * Replace Latin1 character remnant with escaped UTF-8 sequence
  * Cleanup comments for MS Office mimetypes in typesForMimetype
  * Remove unused wdfInc parameter for addTerm and addPositionTerm
  * Use append instead of operator+= when appending to an QVector<int>
  * Do not add Type::Document/Presentation/Spreadsheet twice for MS Office docs
  * Add missing return in error/fixup path
  * actually initialize kcrash properly
  * Add unittest for document replacement
  * Make sure there is only one MTime per document in the MTimeDB
  * Extend diagnostic output for DB autotests
  * Use new syntax
  * [Extractor] Use QDataStream serialization in place of cooked one
  * [Extractor] Replace homegrown IO handler with QDataStream, catch HUP
  * Unbreak build with BUILD_QCH=TRUE
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Too many changes to list here
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Add calls to KIO::UDSEntry::reserve in timeline/tags ioslaves
  * [balooctl] Flush buffered "Indexing <file>" line when indexing starts
  * [FileContentIndexer] Connect finished signal from extractor process
  * [PositionCodec] Avoid crash in case of corrupt data (kde#367480)
  * Fix invalid char constant
  * [Balooctl] remove directory parent check (kde#396535)
  * Allow removing non-existent folders from include and exclude lists (kde#375370)
  * Use non deprecated fastInsert in baloo
  * Use String to store UDS_USER and UDS_GROUP of String type. (kde#398867)
  * [tags_kio] Fix parenthesis. Somehow this got by my code checker.
  * [tags_kio] Remove intermediate QString.
  * Use QString's multi-arg with multiple string args
  * Avoid potential detach on range-loops with non-const Qt containers
  * Compile with strict compile flags
  * Exclude genome files from indexing
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Fixed a typo in the index size output (kde#397843)
  * Remove src not dest url when a url is newly unindexable.
  * [tags_kio] Simplify the filename path query matching by using a capture group.
  * Revert "Skip queueing newly unindexable files and remove them from the index immediately."
  * [tags_kio] Simplify file path lookup while loop.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * [tags_kio] Clean up parser debug and comments.
  * [tags_kio] Fix multiple filename copies.
  * Revert "[tags_kio] Use UDS_URL instead of UDS_TARGET_URL."
  * [tags_kio] Use UDS_URL instead of UDS_TARGET_URL.
  * [tags_kio] Query target filepaths instead of appending paths to the file UDS entry.
  * Support special URLs for finding files of a certain type
  * Avoid manipulation of lists with quadratic complexity
  * Use non deprecated fastInsert in baloo
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove unused entry X-KDE-DBus-ModuleName from the kded plugin metadata
  * [tags_kio] The url query should be a key-value pair.
  * The power state signal should only be emitted when the power state changes.
  * baloodb: Make changes to cmdline arg description after rename prune -> clean
  * Clearly show duplicate filenames in tag folders.
* Thu Jun 14 2018 wbauer@tmo.at
- Recommend corresponding lang packages
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Terminate query execution early if subterm returns empty result set
  * Avoid crash when reading corrupt data from document terms db (kde#392878)
  * Use override
  * handle string lists as input
  * fix some issues reported by clazy
  * Ignore more types of source files (kde#394002, kde#390932)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Avoid infinite loops when fetching the URL from DocumentUrlDB (kde#378754)
  * add missing license
  * add Baloo DBus signals for moved or removed files
  * Add missing override
  * Fix extract i18n from .h file
  * [API dox] Note CamelCase include commands for classes
  * Install pri file for qmake support & document it in metainfo.yaml
  * baloodb: Add clean command
  * balooshow: Colorize only when attached to terminal
  * Remove FSUtils::getDirectoryFileSystem
  * Avoid hardcoding of filesystems supporting CoW
  * Allow disabling of CoW to fail when not supported by filesystem
  * databasesanitizer: Use flags for filtering
  * Fix merging of terms in the AdvancedQueryParser
  * Use QStorageInfo instead of a homegrown implementation
  * sanitizer: Improve device listing
  * fix message ectraction by using find
  * Immediately apply termInConstruction when term is complete
  * Handle adjacent special characters correctly (kde#392620)
  * Add test case for parsing of double opening '(('
  * Fix another syntax error on windows build
  * Fix syntax error on windows build
  * Use statbuf consistently
* Tue Apr 17 2018 fabian@ritter-vogt.de
- Split baloo5-lang into subpackages
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make list of subterms in debug output easier to spot
  * Simplify Term operator&& and ||
  * advancedqueryparsertest: Add more tests
  * Do not retrieve document ID for skipped result entries
  * Do not retrieve mtime from database repeatedly when sorting
  * Fix unitialized value warning, nullptr access
  * Do not export databasesanitizer by default
  * baloodb: Add experimental message
  * Introduce baloodb CLI tool
  * sanitizer: Move implementation into Baloo namespace
  * Introduce sanitizer class
  * autotests: Refactor fileindexerconfigtest
  * [FileIndexerConfig] Delay populating folders until actually used
  * src/kioslaves/search/CMakeLists.txt - link to Qt5Network following changes to kio
  * Remove not necessary QtCore and co
  * balooctl: checkDb should also verify the last known url for the documentId.
  * balooctl monitor: Resume to wait for service
  * autotest: port to QSignalSpy::wait().
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * balooctl: Remove checkDb option (kde#380465)
  * indexerconfig: Describe some functions
  * indexerconfig: Expose canBeSearched function
  * balooctl monitor: Wait for dbus interface
  * fileindexerconfig: Introduce canBeSearched()
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * baloo-tools: Make all output messages translatable
  * build baloo executables with "ecm_mark_nongui"
  * balooctl status: Produce parseable output
  * Fix KIO Slave tagged folder deep copies. This breaks listing tagged folders in the tag tree, but is better than broken copies.
  * Skip queueing newly unindexable files and remove them from the index immediately.
  * Revert "Changing file xattrs (tag, rating, comment) should cause a file to be reindexed. If the ctime changed, the file can be reindexed."
  * baloosearch: Send summary to stderr
  * balooctl status: translatable message
  * Delete newly unindexable moved files from the index.
  * Simplify BasicIndexingJob xattr indexing.
  * Changing file xattrs (tag, rating, comment) should cause a file to be reindexed. If the ctime changed, the file can be reindexed.
  * validate baloo_file.desktop
  * balooctl use global fileIndexDbPath().
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * balooctl status: process all arguments
  * Remove obsolete reviewboardrc file
  * Fix multiple word tag queries.
  * Simplify rename conditions.
  * Fix incorrect UDSEntry display name.
  * Make it compiles with autogenerated debug file
  * Revert "Revert "Autogenerate debug file""
  * Revert "Autogenerate debug file" I'm backing all of this out for now as fixing this properly is non-trivial and the build is broken on at least one platform due to this change.
  * Revert "Complete removal of references to baloodebug.cpp which was deleted in the previous commit"
  * Complete removal of references to baloodebug.cpp which was deleted in the previous commit
  * Autogenerate debug file
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Jenkins build fix. (type change)
  * Strip down and re-write the baloo tags KIO slave (kde#314373, kde#340098, kde#376229, kde#332214, kde#340099)
  * Remove unused config.h.cmake entries
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Consider DjVu files to be documents (kde#369195)
  * Fix spelling so WPS Office presentations are recognized correctly
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Don't enter test subdirectories if BUILD_TESTING=OFF
  * Only match real MIME types, not e.g. "raw CD image" (kde#364884)
  * Remove pf.path() from container before the reference got screwed up by it.remove()
  * Fix tags KIO-slave protocol description
  * Consider markdown files to be Documents
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Avoid useless copies from it.next(), add const REVIEW: 129378
  * Remove useless includes REVIEW: 129650
  * Fix directory based search.
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Fix compilation with cmake current git and cmake >= 3.10
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Use FindInotify.cmake to decide wheter inotify is available.
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Fix title of FAQ doc
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Rename the translation catalogs (avoid conflicts)
  * balooctl, baloosearch, balooshow: Fix order of QCoreApplication object creation (kde#378539)
  * balooshow: fix typo (kde#369470)
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Change some types and exclude filters
  * Added description for commands (balooctl)
  * Search also in symlinked directories
  * Fixed normalization/toLower order
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Implement nested tags. REVIEW: 128664
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Performance improvements when writing
    (4 * speedup for writing out data)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Use correct config entry in autostart condition
  * Fix sorted insert (aka flat_map like insert)
    (kde#367991)
  * Add missing close env, as pointed out by Loïc Yhuel
    (kde#353783)
  * Transaction not created => don't try to abort them
  * fix missing m_env = nullptr assignment
  * Make e.g. Baloo::Query thread safe
  * On 64-bit systems baloo allows now > 5 GB index storage
    (kde#364475)
  * Allow ctime/mtime == 0
    (kde#355238)
  * Handle corruption of index database for baloo_file, try to recreate the database or abort if that fails
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed patches:
  0001-fix-baloo_file-crash-with-corrupted-database.patch
  0003-allow-ctime-mtime-0.patch (kde#355238)
  0004-Increase-size-limit-of-baloo-index-for-64-bit-machin.patch
  (kde#364475)
  0005-Make-e.g.-Baloo-Query-thread-safe.patch
  0006-fix-typo.patch
  0007-fix-missing-m_env-nullptr-assignment.patch
  0008-Transaction-not-created-don-t-try-to-abort-them.patch
  0009-add-missing-close-env-as-pointed-out-by-Lo-c-Yhuel.patch
  (kde#353783)
  0010-Fix-sorted-insert-aka-flat_map-like-insert.patch (kde#367991)
  0011-Open-baloo-lmdb-database-read-only-beside-in-baloo_f.patch
  0012-Use-correct-config-entry-in-autostart-condition.patch
* Fri Oct  7 2016 hrvoje.senjan@gmail.com
- Baloo housekeeping:
  0001-fix-baloo_file-crash-with-corrupted-database.patch
  0003-allow-ctime-mtime-0.patch (kde#355238)
  0004-Increase-size-limit-of-baloo-index-for-64-bit-machin.patch
  (kde#364475)
  0005-Make-e.g.-Baloo-Query-thread-safe.patch
  0006-fix-typo.patch
  0007-fix-missing-m_env-nullptr-assignment.patch
  0008-Transaction-not-created-don-t-try-to-abort-them.patch
  0009-add-missing-close-env-as-pointed-out-by-Lo-c-Yhuel.patch
  (kde#353783)
  0010-Fix-sorted-insert-aka-flat_map-like-insert.patch (kde#367991)
  0011-Open-baloo-lmdb-database-read-only-beside-in-baloo_f.patch
  0012-Use-correct-config-entry-in-autostart-condition.patch
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * DocumentUrlDB::del Only assert when children of dir
    actually exist
  * Ignore malformed Queries which have a binary operator
    without first argument
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Fix using spaces in the tags kioslave (kde#349118)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Compilation fixes for Windows
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Centralize batch size in config
  * Remove code blocking indexing of text/plain files
    without .txt extension (kde#358098)
  * Check both, filename and filecontent to determine mimetype
    (kde#353512)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
- Drop upstreamed Do-not-block-indexing-of-text-plain-files-without-txt-extension.patch
* Tue Mar 22 2016 wbauer@tmo.at
- Added Do-not-block-indexing-of-text-plain-files-without-txt-extension.patch
  from upstream: fixes indexing of text/plain files without .txt
  extension (kde#358098)
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Fix several issue of mtime related search
  * PostingDB Iter: Do not assert on MDB_NOTFOUND
  * Balooctl status: Avoid showing 'Content indexing' about folders
  * StatusCommand: Show the correct status for folders
  * SearchStore: Gracefully handle empty term values (kde#356176)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Fix date filter used by timeline://
  * BalooCtl: Return after commands
  * Clean up and armour Baloo::Database::open(), handle more
    crash conditions
  * Add check in Database::open(OpenDatabase) to fail if
    db doesn't exist
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Thu Nov 12 2015 alarrosa@suse.com
- Added fix-cmakelists-comments.diff: change cmake 3.0 block
  comments to work with cmake 2.x
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Monitor lib: Use Kformat::spelloutDuration to localize
    time string
  * Use KDE_INSTALL_DBUSINTERFACEDIR to install dbus interfaces
  * UnindexedFileIndexer: Handle files that have been moved when
    baloo_file was not running
  * Remove Transaction::renameFilePath and add
    DocumentOperation for it.
  * Make constructors with a single parameter explicit
  * UnindexedFileIndexer: only index required parts of file
  * Transaction: add method to return timeInfo struct
  * Added exclude mimetypes to balooctl's config
  * Databases: Use QByteArray::fromRawData when passing data
    to a codec
  * Balooctl: Move 'status' command to its own class
  * Balooctl: Show help menu if the command is not recognized
  * Balooshow: Allow us to lookup files by their inode + devId
  * Balooctl monitor: stop if baloo dies
  * MonitorCommand: Use both the started and finished signals
  * Balooctl monitor: Move to a proper command class
  * Add dbus notification for when we start/finish
    indexing a file
  * FileIndexScheduler: Forcibly kill threads on exit
  * WriteTransaction commit: Avoid fetching the positionList
    unless required
  * WriteTransaction: Extra asserts in replaceDocument
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix limit/offset handling in SearchStore::exec
  * Recreate the baloo index
  * balooctl config: add options to set/view onlyBasicIndexing
  * Port balooctl check to work with new architecture (kde#353011)
  * FileContentIndexer: fix emitting filePath twice
  * UnindexedFileIterator: mtime is quint32 not quint64
  * Transaction: fix another Dbi typo
  * Transaction: Fix documentMTime() and documentCTime()
    using wrong Dbis.
  * Transaction::checkPostingDbInTermsDb: Optimize code
  * Fix dbus warnings
  * Balooctl: Add checkDb command
  * balooctl config: Add "exclude filter"
  * KF5Baloo: Make sure D-Bus interfaces are generated before they
    are used. (kde#353308)
  * Avoid using QByteArray::fromRawData
  * Remove baloo-monitor from baloo
  * TagListJob: Emit error when failed to open database
  * Do not ignore subterms if not found
  * Cleaner code for failing Baloo::File::load() on DB open fail.
  * Make balooctl use IndexerConfig instead of manipulating
    baloofilerc directly
  * Improve i18n for balooshow
  * Make balooshow fail gracefully if database cannot be opened.
  * Fail Baloo::File::load() if the Database is not open.
    (kde#353049)
  * IndexerConfig: add refresh() method
  * inotify: Do not simulate a closedWrite event after
    move without cookie
  * ExtractorProcess: Remove the extra \n at the end of
    the filePath
  * baloo_file_extractor: call QProcess::close before
    destroying the QProcess
  * baloomonitorplugin/balooctl: i18nize indexer state.
  * BalooCtl: Add a 'config' option
  * Make baloosearch more presentable
  * Remove empty EventMonitor files
  * BalooShow: Show more information when the ids do not match
  * BalooShow: When called with an id check if the id is correct
  * Add a FileInfo class
  * Add error checking in various bits so that Baloo doesn't
    crash when disabled. (kde#352454)
  * Fix Baloo not respecting "basic indexing only" config option
  * Monitor: Fetch remaining time on startup
  * Use actual method calls in MainAdaptor instead
    of QMetaObject::invokeMethod
  * Add org.kde.baloo interface to root object for
    backward compatibility
  * Fix date string displayed in address bar due to
    porting to QDate
  * Add delay after each file instead of each batch
  * Remove Qt::Widgets dependency from baloo_file
  * Remove unused code from baloo_file_extractor
  * Add baloo monitor or experimental qml plugin
  * Make "querying for remaining time" thread safe
  * kioslaves: Add missing override for virtual functions
  * Extractor: Set the applicationData after constructing the app
  * Query: Implement support for 'offset'
  * Balooctl: Add --version and --help (kde#351645)
  * Remove KAuth support to increase max inotify watches if
    count too low (kde#351602)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
- Drop upstreamed patches:
  0001-Fix-Baloo-not-respecting-basic-indexing-only-config-.patch
  0002-Add-error-checking-in-various-bits-so-that-Baloo-doe.patch
  0003-Fail-Baloo-File-load-if-the-Database-is-not-open.patch
  0004-Cleaner-code-for-failing-Baloo-File-load-on-DB-open-.patch
  0005-TagListJob-Emit-error-when-failed-to-open-database.patch
* Mon Sep 28 2015 hrvoje.senjan@gmail.com
- Added patches from upstream to resolve various issues when user
  has file indexing disabled:
  0001-Fix-Baloo-not-respecting-basic-indexing-only-config-.patch
  0002-Add-error-checking-in-various-bits-so-that-Baloo-doe.patch
  0003-Fail-Baloo-File-load-if-the-Database-is-not-open.patch
  0004-Cleaner-code-for-failing-Baloo-File-load-on-DB-open-.patch
  0005-TagListJob-Emit-error-when-failed-to-open-database.patch
* Wed Sep  9 2015 alarrosa@suse.com
- Added installed files to the %%files section to fix build
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Add org.kde.baloo interface to root object
    for backward compatibility
  * Install a fake org.kde.baloo.file.indexer.xml to
    fix compilation of plasma-desktop 5.4
  * Re-organize D-Bus interfaces
  * Use json metadata in kded plugin and fix plugin name
  * Create one Database instance per process (kde#350247)
  * Prevent baloo_file_extractor being killed while committing
  * Generate xml interface file using qt5_generate_dbus_interface
  * Baloo monitor fixes
  * Move file url export to main thread
  * Make sure cascaded configs are taken into account
  * Do not install namelink for private library
  * Install translations, spotted by Hrvoje Senjan.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
- Drop 0001-install-translations.patch, merged upstream
- Drop krunner-devel BuildRequires, no longer needed
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
- Added 0001-install-translations.patch from upstream
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
- Drop 0001-Revert-BasicIndexingQueue-Use-xapian-slots-to-fetch-.patch,
  merged upstream
* Sat May  2 2015 hrvoje.senjan@gmail.com
- Added 0001-Revert-BasicIndexingQueue-Use-xapian-slots-to-fetch-.patch
  from upstream
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Let file and tools subpackages Obsolete KDE4 variants for
  openSUSE > 13.2
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Raise required extra-cmake-modules version to 1.2.0
- Added kdbusaddons-devel BuildRequires
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Added baselibs.conf
- Drop kcmutils-devel BuildRequires
- Add recommends for lang subpackage
- New libKF5Baloo1 shlib replaces libKF5BalooNaturalQueryParser1,
  libKF5BalooFiles1 and libKF5BalooCore1
- Remove not needed Obsoletes
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
- (Build)Require equal version of kfilemetadata5-devel
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Escape dots in exclude filters, kde#339908
  * BasicIQ: Fix broken indexing on file modifications when
    file exists
  * Fix build with Qt 5.4
  * BasicIQ: Fetch the id before indexing it
  * Enforce a maxiumum term size of 25
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API adjustements since previous snapshot
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Sep 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140911 (rb92aa3b):
  * Use QPluginLoader instead of KService.
  * New naturalqueryparser library
  * API cleanups
  * Various bugfixes
  * Added QML components
- Drop kservice-devel BuildRequires, per upstream changes
- Added pkgconfig(Qt5Quick) BuildRequires
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Sun Jul 27 2014 hrvoje.senjan@gmail.com
- Added libQt5Sql5-sqlite Requires to file subpackage
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Thu Jun  5 2014 hrvoje.senjan@gmail.com
- Activate baloo5 package
